class GroupsController < ApplicationController

  before_filter :find_group, :only => [:show, :edit, :update, :destroy]

  rescue_from ActiveRecord::RecordNotFound, :with => :bad_record

  helper :sort
  include SortHelper


  def index
    @html_title = "Browse Groups"
    sort_init 'id'
    sort_update
    @query = params[:query]
    @field = %w(name description).detect{|f| f == (params[:field])}
    if @query && @query.strip.length > 0 && @field
      conditions = ["#{@field}  LIKE?", '%'+@query+'%']
    else
      conditions = nil
    end

    @groups = Group.paginate(:page => params[:page],:per_page => 20, :order => "updated_at DESC",  :conditions => conditions)
  end


  def show
    @group_users = @group.users.paginate(:page => params[:page], :per_page => 100, :order => "memberships.created_at DESC")
    @html_title = "Showing Group " + @group.id.to_s
    @comments = @group.comments.recent.paginate(:page => params[:page], :per_page => 5, :order => "comments.created_at DESC")

  end


  def new
    @group = Group.new
  end


  def create
    @group = Group.new(params[:group])
    @group.creator = current_user
    if @group.save
      flash[:notice] = "New Group Created!"
      redirect_to group_url(@group)
    else
      render :action => 'new'
    end
  end


  def edit

  end


  def update
    if @group.update_attributes(params[:group])
      flash[:notice] = "Successfully updated group."
      redirect_to group_url(@group)
    else
      render :action => 'edit'
    end
  end


  def destroy
  # if (group.creator == current_user) or admin_authorized?
      if @group.destroy
        flash[:notice] = "Group deleted!"
      else
        flash[:notice] = "Group couldn't be deleted."
      end

    redirect_to groups_path
  end

  def add_comment
  
    commentable_type = params[:commentable][:commentable]
    commentable_id = params[:commentable][:commentable_id]
    # Get the object that you want to comment
    commentable = Comment.find_commentable(commentable_type, commentable_id)

    # Create a comment with the user submitted content
    comment = Comment.new(params[:comment])
    # Assign this comment to the logged in user
    comment.user_id = current_user.id

    # Add the comment
    commentable.comments << comment

    redirect_to groups_path
  end

  private

  def find_group
    @group = Group.find(params[:id])
  end
  
end
