class User < ActiveRecord::Base
  # Include default devise modules. Others available are:
  # :token_authenticatable, :lockable, :timeoutable, :confirmable and :activatable
  devise :database_authenticatable, :registerable, 
         :recoverable, :rememberable, :trackable, :validatable

  # Setup accessible (or protected) attributes for your model
  attr_accessible :email, :password, :password_confirmation, :username, :skype, :language, :image

  validates :email, :uniqueness => true

  validates :username, :presence => true, :uniqueness => true


#  validates :image, :format => {
#    :with    => %r{\.(gif|jpg|png)$}i,
#    :message => 'must be a URL for GIF, JPG or PNG image.'
#  }

   has_many :memberships, :dependent => :destroy
   has_many :groups, :through => :memberships

   has_and_belongs_to_many :languages

   has_many :microposts, :dependent => :destroy

   has_many :relationships, :foreign_key => "follower_id",
                           :dependent => :destroy
   has_many :following, :through => :relationships, :source => :followed

   has_many :reverse_relationships, :foreign_key => "followed_id",
                                   :class_name => "Relationship",
                                   :dependent => :destroy
   has_many :followers, :through => :reverse_relationships, :source => :follower

  def following?(followed)
    relationships.find_by_followed_id(followed)
  end

  def follow!(followed)
    relationships.create!(:followed_id => followed.id)
  end
  
  def unfollow!(followed)
    relationships.find_by_followed_id(followed).destroy
  end
  def feed
    Micropost.from_users_followed_by(self)
  end
end
